@@ -1,4 +1,4 @@
 #!/bin/sh
 
 echo "Cheese log:"
-cat $HOME/.gnome2/cheese/log
+cat $HOME/.gnome2/cheese/log.txt
